Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys "peripheral", not "peripherial".



details:   https://anonhg.NetBSD.org/src/rev/47e4572fc5e1
branches:  trunk
changeset: 330545:47e4572fc5e1
user:      dholland <dholland%NetBSD.org@localhost>
date:      Sun Jul 13 17:12:23 2014 +0000

description:
"peripheral", not "peripherial".

diffstat:

 sys/arch/arm/cortina/files.g2 |   4 ++--
 sys/arch/sgimips/hpc/pi1ppc.c |   6 +++---
 sys/dev/ic/atppc.c            |   6 +++---
 sys/dev/ppbus/ppbus_1284.c    |   6 +++---
 sys/dev/ppbus/ppbus_base.c    |   6 +++---
 sys/dev/scsipi/scsipi_base.c  |  10 +++++-----
 sys/dev/scsipi/scsipiconf.h   |  14 +++++++-------
 sys/dev/spi/spivar.h          |   4 ++--
 8 files changed, 28 insertions(+), 28 deletions(-)

diffs (244 lines):

diff -r 89c9f6103400 -r 47e4572fc5e1 sys/arch/arm/cortina/files.g2
--- a/sys/arch/arm/cortina/files.g2     Sun Jul 13 16:35:49 2014 +0000
+++ b/sys/arch/arm/cortina/files.g2     Sun Jul 13 17:12:23 2014 +0000
@@ -1,4 +1,4 @@
-#      $NetBSD: files.g2,v 1.1 2013/02/19 16:07:23 matt Exp $
+#      $NetBSD: files.g2,v 1.2 2014/07/13 17:12:23 dholland Exp $
 #
 # Configuration info for Broadcom BCM5301X ARM Peripherals
 #
@@ -22,7 +22,7 @@
 defflag opt_cortina.h                          G2_CONSOLE_EARLY
 defflag opt_cortina.h                          G2ETH_COUNTERS
 
-# G2 Peripherial attach point
+# G2 Peripheral attach point
 device g2periph { [channel=-1] } : bus_space_generic
 attach g2periph at mainbus
 file   arch/arm/cortina/g2_periph.c            g2periph        needs-flag
diff -r 89c9f6103400 -r 47e4572fc5e1 sys/arch/sgimips/hpc/pi1ppc.c
--- a/sys/arch/sgimips/hpc/pi1ppc.c     Sun Jul 13 16:35:49 2014 +0000
+++ b/sys/arch/sgimips/hpc/pi1ppc.c     Sun Jul 13 17:12:23 2014 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: pi1ppc.c,v 1.11 2011/07/01 18:53:47 dyoung Exp $ */
+/* $NetBSD: pi1ppc.c,v 1.12 2014/07/13 17:12:23 dholland Exp $ */
 
 /*
  * Copyright (c) 2001 Alcove - Nicolas Souchu
@@ -33,7 +33,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pi1ppc.c,v 1.11 2011/07/01 18:53:47 dyoung Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pi1ppc.c,v 1.12 2014/07/13 17:12:23 dholland Exp $");
 
 #include "opt_pi1ppc.h"
 
@@ -1217,7 +1217,7 @@
                        ctr &= ~HOSTBUSY;
                        pi1ppc_w_ctr(pi1ppc, ctr);
 
-                       /* Event 11 - wait ack from peripherial */
+                       /* Event 11 - wait ack from peripheral */
                        if (pi1ppc->sc_use & PI1PPC_USE_INTR)
                                pi1ppc->sc_inerr = pi1ppc_wait_interrupt(pi1ppc,
                                    &pi1ppc->sc_in_cv, PI1PPC_IRQ_nACK);
diff -r 89c9f6103400 -r 47e4572fc5e1 sys/dev/ic/atppc.c
--- a/sys/dev/ic/atppc.c        Sun Jul 13 16:35:49 2014 +0000
+++ b/sys/dev/ic/atppc.c        Sun Jul 13 17:12:23 2014 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: atppc.c,v 1.31 2014/06/04 21:42:35 wiz Exp $ */
+/* $NetBSD: atppc.c,v 1.32 2014/07/13 17:12:23 dholland Exp $ */
 
 /*
  * Copyright (c) 2001 Alcove - Nicolas Souchu
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: atppc.c,v 1.31 2014/06/04 21:42:35 wiz Exp $");
+__KERNEL_RCSID(0, "$NetBSD: atppc.c,v 1.32 2014/07/13 17:12:23 dholland Exp $");
 
 #include "opt_atppc.h"
 
@@ -1663,7 +1663,7 @@
                        ctr &= ~HOSTBUSY;
                        atppc_w_ctr(atppc, ctr);
 
-                       /* Event 11 - wait ack from peripherial */
+                       /* Event 11 - wait ack from peripheral */
                        if (atppc->sc_use & ATPPC_USE_INTR)
                                atppc->sc_inerr = atppc_wait_interrupt(atppc,
                                        &atppc->sc_in_cv, ATPPC_IRQ_nACK);
diff -r 89c9f6103400 -r 47e4572fc5e1 sys/dev/ppbus/ppbus_1284.c
--- a/sys/dev/ppbus/ppbus_1284.c        Sun Jul 13 16:35:49 2014 +0000
+++ b/sys/dev/ppbus/ppbus_1284.c        Sun Jul 13 17:12:23 2014 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: ppbus_1284.c,v 1.12 2008/04/18 14:56:40 cegger Exp $ */
+/* $NetBSD: ppbus_1284.c,v 1.13 2014/07/13 17:12:23 dholland Exp $ */
 
 /*-
  * Copyright (c) 1997 Nicolas Souchu
@@ -32,7 +32,7 @@
 /* General purpose routines for the IEEE1284-1994 Standard */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ppbus_1284.c,v 1.12 2008/04/18 14:56:40 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ppbus_1284.c,v 1.13 2014/07/13 17:12:23 dholland Exp $");
 
 #include "opt_ppbus_1284.h"
 
@@ -47,7 +47,7 @@
 #include <dev/ppbus/ppbus_var.h>
 
 
-/* Wait for the peripherial up to 40ms */
+/* Wait for the peripheral up to 40ms */
 static int
 do_1284_wait(struct ppbus_softc * bus, char mask, char status)
 {
diff -r 89c9f6103400 -r 47e4572fc5e1 sys/dev/ppbus/ppbus_base.c
--- a/sys/dev/ppbus/ppbus_base.c        Sun Jul 13 16:35:49 2014 +0000
+++ b/sys/dev/ppbus/ppbus_base.c        Sun Jul 13 17:12:23 2014 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: ppbus_base.c,v 1.18 2011/05/13 22:35:51 rmind Exp $ */
+/* $NetBSD: ppbus_base.c,v 1.19 2014/07/13 17:12:23 dholland Exp $ */
 
 /*-
  * Copyright (c) 1997, 1998, 1999 Nicolas Souchu
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ppbus_base.c,v 1.18 2011/05/13 22:35:51 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ppbus_base.c,v 1.19 2014/07/13 17:12:23 dholland Exp $");
 
 #include "opt_ppbus_1284.h"
 #include "opt_ppbus.h"
@@ -506,7 +506,7 @@
        return (NULL);
 }
 
-/* Stores the class ID of the peripherial in soft config data */
+/* Stores the class ID of the peripheral in soft config data */
 void
 ppbus_pnp_detect(device_t dev)
 {
diff -r 89c9f6103400 -r 47e4572fc5e1 sys/dev/scsipi/scsipi_base.c
--- a/sys/dev/scsipi/scsipi_base.c      Sun Jul 13 16:35:49 2014 +0000
+++ b/sys/dev/scsipi/scsipi_base.c      Sun Jul 13 17:12:23 2014 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: scsipi_base.c,v 1.159 2012/04/20 20:23:21 bouyer Exp $ */
+/*     $NetBSD: scsipi_base.c,v 1.160 2014/07/13 17:12:23 dholland Exp $       */
 
 /*-
  * Copyright (c) 1998, 1999, 2000, 2002, 2003, 2004 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: scsipi_base.c,v 1.159 2012/04/20 20:23:21 bouyer Exp $");
+__KERNEL_RCSID(0, "$NetBSD: scsipi_base.c,v 1.160 2014/07/13 17:12:23 dholland Exp $");
 
 #include "opt_scsi.h"
 
@@ -376,7 +376,7 @@
  * scsipi_get_xs:
  *
  *     Allocate an xfer descriptor and associate it with the
- *     specified peripherial.  If the peripherial has no more
+ *     specified peripheral.  If the peripheral has no more
  *     available command openings, we either block waiting for
  *     one to become available, or fail.
  */
@@ -484,9 +484,9 @@
  * scsipi_put_xs:
  *
  *     Release an xfer descriptor, decreasing the outstanding command
- *     count for the peripherial.  If there is a thread waiting for
+ *     count for the peripheral.  If there is a thread waiting for
  *     an opening, wake it up.  If not, kick any queued I/O the
- *     peripherial may have.
+ *     peripheral may have.
  *
  *     NOTE: Must be called at splbio().
  */
diff -r 89c9f6103400 -r 47e4572fc5e1 sys/dev/spi/spivar.h
--- a/sys/dev/spi/spivar.h      Sun Jul 13 16:35:49 2014 +0000
+++ b/sys/dev/spi/spivar.h      Sun Jul 13 17:12:23 2014 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: spivar.h,v 1.5 2014/02/28 10:16:51 skrll Exp $ */
+/* $NetBSD: spivar.h,v 1.6 2014/07/13 17:12:23 dholland Exp $ */
 
 /*-
  * Copyright (c) 2006 Urbana-Champaign Independent Media Center.
@@ -49,7 +49,7 @@
 /*
  * Serial Peripheral Interface bus.  This is a 4-wire bus common for
  * connecting flash, clocks, sensors, and various other low-speed
- * peripherials.
+ * peripherals.
  */
 
 struct spi_handle;



Home | Main Index | Thread Index | Old Index
diff -r 89c9f6103400 -r 47e4572fc5e1 sys/dev/scsipi/scsipiconf.h
--- a/sys/dev/scsipi/scsipiconf.h       Sun Jul 13 16:35:49 2014 +0000
+++ b/sys/dev/scsipi/scsipiconf.h       Sun Jul 13 17:12:23 2014 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: scsipiconf.h,v 1.121 2012/04/20 20:23:21 bouyer Exp $  */
+/*     $NetBSD: scsipiconf.h,v 1.122 2014/07/13 17:12:23 dholland Exp $        */
 
 /*-
  * Copyright (c) 1998, 1999, 2000, 2004 The NetBSD Foundation, Inc.
@@ -79,7 +79,7 @@
  * scsipi_async_event_t:
  *
  *     Asynchronous events from the adapter to the mid-layer and
- *     peripherial.
+ *     peripheral.
  *
  *     Arguments:
  *
@@ -346,7 +346,7 @@
 /*
  * scsipi_periph:
  *
  *     This structure describes the path between a peripherial device
  *     and an adapter.  It contains a pointer to the adapter channel
  *     which in turn contains a pointer to the adapter.
  *
@@ -357,13 +357,13 @@
  *     still be an improvement.
  */
 struct scsipi_periph {
-       device_t periph_dev;    /* pointer to peripherial's device */
+       device_t periph_dev;    /* pointer to peripheral's device */
        struct scsipi_channel *periph_channel; /* channel we're connected to */
 
                                        /* link in channel's table of periphs */
        LIST_ENTRY(scsipi_periph) periph_hash;
 
-       const struct scsipi_periphsw *periph_switch; /* peripherial's entry
+       const struct scsipi_periphsw *periph_switch; /* peripheral's entry
                                                        points */
        int     periph_openings;        /* max # of outstanding commands */
        int     periph_active;          /* current # of outstanding commands */
@@ -393,7 +393,7 @@
        /* Bitmap of free command tags. */
        u_int32_t periph_freetags[PERIPH_NTAGWORDS];
 
        /* Pending scsipi_xfers on this peripherial. */
        struct scsipi_xfer_queue periph_xferq;
 
        callout_t periph_callout;
@@ -512,7 +512,7 @@
        callout_t xs_callout;           /* callout for adapter use */
        int     xs_control;             /* control flags */
        volatile int xs_status;         /* status flags */
-       struct scsipi_periph *xs_periph;/* peripherial doing the xfer */
+       struct scsipi_periph *xs_periph;/* peripheral doing the xfer */
        int     xs_retries;             /* the number of times to retry */
        int     xs_requeuecnt;          /* number of requeues */
        int     timeout;                /* in milliseconds */
@@ -346,7 +346,7 @@
  * scsipi_periph:
  *
- *     This structure describes the path between a peripherial device
+ *     This structure describes the path between a peripheral device
  *     and an adapter.  It contains a pointer to the adapter channel
  *     which in turn contains a pointer to the adapter.
@@ -393,7 +393,7 @@
        u_int32_t periph_freetags[PERIPH_NTAGWORDS];
 
-       /* Pending scsipi_xfers on this peripherial. */
+       /* Pending scsipi_xfers on this peripheral. */
        struct scsipi_xfer_queue periph_xferq;
 